<?php
/**
 *  Exit if accessed directly
 *
 * @package  Wt_Sl_Google_Settings
 * @version  1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Wt_Sl_Google_Settings.
 *
 * @since 1.0.0
 */
class Wt_Sl_Google_Settings {

	/**
	 * Wt_sl_google_enable.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_sl_google_enable() {

		/* Translators: %s Docs URL. */
		echo wp_kses_post( sprintf( __( '<p> You need to create a <a href="%s" target="_blank">Google application</a> prior to start using the Google for social login. </p>', 'wt-social-login' ), 'https://console.developers.google.com/apis/' ) );
	}

	/**
	 * Wt_social_login_enable_google.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_social_login_enable_google() {
		echo '<input value="1" type="checkbox" id="wt_social_login_enable_google" name="wt_social_login_enable_google" ' . checked( 1, get_option( 'wt_social_login_enable_google' ), false ) . ' />';
	}

	/**
	 * Wt_social_login_google_app_id.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_social_login_google_app_id() {
		$wt_social_login_google_app_id = get_option( 'wt_social_login_google_app_id' );
		echo '<input type="text" name="wt_social_login_google_app_id" id="wt_social_login_google_app_id" value="' . esc_attr( $wt_social_login_google_app_id ) . '">';
	}

	/**
	 * Wt_social_login_google_app_secret.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_social_login_google_app_secret() {
		$wt_social_login_google_app_secret = get_option( 'wt_social_login_google_app_secret' );
		echo '<input type="text" name="wt_social_login_google_app_secret" id="wt_social_login_google_app_secret" value="' . esc_attr( $wt_social_login_google_app_secret ) . '">';
	}

	/**
	 * Wt_social_login_google_callback_url.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_social_login_google_callback_url() {
		$wt_social_login_google_callback_url = get_option( 'wt_social_login_google_callback_url' );
		echo '<input type="text" name="wt_social_login_google_callback_url" id="wt_social_login_google_callback_url" value="' . esc_attr( $wt_social_login_google_callback_url ) . '">';
	}

	/**
	 * Wt_social_login_google_app_instructions.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_social_login_google_app_instructions() {
		?>
		<div class="sl-app-instruction">
			<h2 class="title">Create Google App</h2>
			<ol>
				<li><?php printf(__('Goto %s', 'wt-social-login'), '<a href="https://console.developers.google.com/apis/" target="_blank">Google\'s APIs & Services.</a>'); ?></li>
				<li><?php _e('Log in with your Google credentials.', 'wt-social-login'); ?></li>
				<li><?php _e('If you don\'t have a project yet, you\'ll need to create one. You can do this by clicking on the blue "<b>Create</b>" button on the right side!  ( If you already have a project, click on the name of your project in the dashboard instead, which will bring up a modal and click <b>"New Project"</b> ).', 'wt-social-login'); ?></li>
				<li><?php _e('Name your project and then click on the "<b>Create</b>" button again.', 'wt-social-login'); ?></li>
				<li><?php _e('Once you have a project, you\'ll end up in the dashboard.', 'wt-social-login'); ?></li>
				<li><?php _e('Click the “<b>OAuth consent screen</b>” button on the left hand side.', 'wt-social-login'); ?></li>
				<li><?php _e('Choose a <b>User Type</b> according to your needs. If you want to enable the social login with Google for any users with a Google account, then pick the External option!', 'wt-social-login'); ?>           
					<ul>
						<li><?php printf(__('<b>Note:</b> We don\'t use sensitive or restricted scopes either. But if you will use this App for other purposes too, then you may need to go through an %1$s!', 'wt-social-login'), '<a href="https://support.google.com/cloud/answer/9110914" target="_blank">independent security review</a>'); ?></li>
					</ul>
				</li>
				<li><?php _e('Enter a name for your App to the "<b>Application name</b>" field, which will appear as the name of the app asking for consent.', 'wt-social-login'); ?></li>
				<li><?php printf(__('Fill the "<b>Authorized domains</b>" field with your domain name, eg: <b>%s</b> without subdomains!', 'wt-social-login'), 'mydomain.com'); ?></li>
				<li><?php _e('Save your settings!', 'wt-social-login'); ?></li>
				<li><?php printf(__('On the left side, click on the "<b>%1$s</b>" menu point, then click the "<b>%2$s</b>" button in the top bar.', 'wt-social-login'), 'Credentials', '+ Create Credentials') ?></li>
				<li><?php _e('Choose the "<b>OAuth client ID</b>" option.', 'wt-social-login'); ?></li>
				<li><?php _e('Select the "<b>Web application</b>" under Application type.', 'wt-social-login'); ?></li>
				<li><?php _e('Enter a "<b>Name</b>" for your OAuth client ID.', 'wt-social-login'); ?></li>
				<li><?php printf(__('Add a redirect URL to the "<b>Authorised redirect URIs</b>" field and also add this in the field: "<b>Google callback URL</b>" of the plugin. eg: <b>%s</b>', 'wt-social-login'), 'https://mydomain.com/wp-login.php'); ?></li>
				<li><?php _e('Click on the "<b>Create</b>" button.', 'wt-social-login'); ?></li>
				<li><?php _e('A modal should pop up with your credentials. If that doesn\'t happen, go to the Credentials in the left hand menu and select your app by clicking on its name and you\'ll be able to copy the "<b>Client ID</b>" and "<b>Client Secret</b>" from there.', 'wt-social-login'); ?></li>
				<li><?php _e('Paste the "<b>Client ID</b>" & "<b>Client Secret</b>" to the fields "<b>Google App ID/API Key</b>" & "<b>Google App Secret</b>" respectively.', 'wt-social-login'); ?></li>
			</ol>
		<div>
		<?php
	}

}
