<?php
/**
 *  Exit if accessed directly
 *
 * @package  Wt_Sl_Linkedin_Settings
 * @version  1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Wt_Sl_Linkedin_Settings.
 *
 * @since 1.0.0
 */
class Wt_Sl_Linkedin_Settings {

	/**
	 * Wt_sl_linkedin_enable.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_sl_linkedin_enable() {

		/* Translators: %s Docs URL. */
		echo wp_kses_post( sprintf( __( '<p> You need to create a <a href="%s" target="_blank">LinkedIn application</a> prior to start using the LinkedIn for social login. </p>', 'wt-social-login' ), 'https://developer.linkedin.com/' ) );
	}

	/**
	 * Wt_social_login_enable_linkedin.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_social_login_enable_linkedin() {
		echo '<input value="1" type="checkbox" id="wt_social_login_enable_linkedin" name="wt_social_login_enable_linkedin" ' . checked( 1, get_option( 'wt_social_login_enable_linkedin' ), false ) . ' />';
	}

	/**
	 * Wt_social_login_linkedin_app_id.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_social_login_linkedin_app_id() {
		$wt_social_login_linkedin_app_id = get_option( 'wt_social_login_linkedin_app_id' );
		echo '<input type="text" name="wt_social_login_linkedin_app_id" id="wt_social_login_linkedin_app_id" value="' . esc_attr( $wt_social_login_linkedin_app_id ) . '">';
	}

	/**
	 * Wt_social_login_linkedin_app_secret.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_social_login_linkedin_app_secret() {
		$wt_social_login_linkedin_app_secret = get_option( 'wt_social_login_linkedin_app_secret' );
		echo '<input type="text" name="wt_social_login_linkedin_app_secret" id="wt_social_login_linkedin_app_secret" value="' . esc_attr( $wt_social_login_linkedin_app_secret ) . '">';
	}

	/**
	 * Wt_social_login_linkedin_callback_url.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_social_login_linkedin_callback_url() {
		$wt_social_login_linkedin_callback_url = get_option( 'wt_social_login_linkedin_callback_url' );
		echo '<input type="text" name="wt_social_login_linkedin_callback_url" id="wt_social_login_linkedin_callback_url" value="' . esc_attr( $wt_social_login_linkedin_callback_url ) . '">';
	}

	/**
	 * Wt_social_login_linkedin_app_instructions.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function wt_social_login_linkedin_app_instructions() {
		?>
		<div class="sl-app-instruction">
			<h2 class="title">Create LinkedIn App</h2>
			<ol>
				<li><?php printf(__('Goto %s', 'wt-social-login'), '<a href="https://developer.linkedin.com/" target="_blank">LinkedIn Developers Page.</a>'); ?></li>
				<li><?php _e('Click the "<b>Create App</b>" link in the header menu.', 'wt-social-login'); ?></li>
				<li><?php _e('Log in with your LinkedIn credentials if you are not logged in.', 'wt-social-login'); ?></li>
				<li><?php _e('To correctly create the application please fill in the sections of the application which are explained below,', 'wt-social-login'); ?></li>
				<ul class="wt-ul-square">
					<li><?php _e('App Name – Enter a name for your application.', 'wt-social-login'); ?></li>
					<li><?php _e('LinkedIn Page – Select an existing LinkedIn page of the company or create a new LinkedIn page.', 'wt-social-login'); ?></li>
					<li><?php _e('Privacy policy URL – Enter the URL for the Privacy policy.', 'wt-social-login'); ?></li>
					<li><?php _e('App logo – Upload an app logo.', 'wt-social-login'); ?></li>
					<li><?php _e('Legal agreement - Read the terms of service and check the box to confirm that you have read and agree to the terms.'); ?></li>
				</ul>
				<li><?php _e('Go to the "<b>Auth</b>" section and edit "<b>Authorized redirect URLs for your app</b>" under the "<b>OAuth 2.0 settings</b>".', 'wt-social-login'); ?></li>
				<li><?php _e('Click the "<b>Add redirect URL</b>" link.', 'wt-social-login'); ?></li>
				<li><?php printf(__('In the redirects URLs, you just need to enter your site\'s login URL and also add this in the "<b>Linkedin callback URL</b>" field of the plugin.e.g: %s', 'wt-social-login'), 'https://www.mydomain.com/wp-login.php'); ?></li>
				<li><?php _e('Select the "<b>Sign In with LinkedIn</b>" product from the "<b>Products</b>" section.', 'wt-social-login'); ?></li>
				<li><?php _e('After a few minutes the product will be listed in your 
				"<b>Added products</b>" list.', 'wt-social-login'); ?></li>
				<li><?php _e('If the app is successfully created then you will need to copy the "<b>Client ID</b>" & "<b>Client Secret</b>" and paste it to the "<b>Linkedin App ID/API Key</b>" & "<b>Linkedin App Secret</b>" fields of the plugin respectively.', 'wt-social-login'); ?></li>
			</ol>
		</div>
		<?php
	}
}
